## ----include=FALSE------------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----vignetteSetup, echo=FALSE, message=FALSE, warning=FALSE------------------
## Bib setup
library(RefManageR)

## Write bibliography information
bib <- c(
    R = citation(),
    BiocStyle = citation("BiocStyle")[1],
    knitr = citation("knitr")[1],
    RefManageR = citation("RefManageR")[1],
    rmarkdown = citation("rmarkdown")[1],
    testthat = citation("testthat")[1]
)

## ----install, eval=FALSE------------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  
#  BiocManager::install("iSEEtree")

## ----start, message=FALSE, warning=FALSE--------------------------------------
library(iSEEtree)
library(mia)
library(scater)

# Import TreeSE
data("Tengeler2020", package = "mia")
tse <- Tengeler2020

# Add relabundance assay
tse <- transformAssay(tse, method = "relabundance")

# Add reduced dimensions
tse <- runMDS(tse, assay.type = "relabundance")

# Launch iSEE
if (interactive()) {
  iSEE(tse)
}

## ----screenfun, eval=!exists("SCREENSHOT"), include=FALSE---------------------
SCREENSHOT <- function(x, ...) knitr::include_graphics(x)

## ----screenplot, echo=FALSE, out.width="100%"---------------------------------
SCREENSHOT("screenshots/get_started.png", delay=20)

## ----citation-----------------------------------------------------------------
## Citation info
citation("iSEEtree")

## ----reproduce, echo=FALSE--------------------------------------------------------------------------------------------
## Session info
options(width = 120)
sessionInfo()

## ----vignetteBiblio, results="asis", echo=FALSE, warning=FALSE, message=FALSE-----------------------------------------
## Print bibliography
PrintBibliography(bib, .opts = list(hyperlink = "to.doc", style = "html"))

